Returns the names of all datatypes currently registered in the bidser runtime registry.
Usage
list_datatypes(scope = c("all", "raw", "derivative", "both"))Returns the names of all datatypes currently registered in the bidser runtime registry.
list_datatypes(scope = c("all", "raw", "derivative", "both"))