Get the sidecar metadata attached to a tabular BIDS object
Source:R/all_generic.R, R/tabulars.R
sidecar.RdGet the sidecar metadata attached to a tabular BIDS object
Examples
# \donttest{
tryCatch({
ds001_path <- get_example_bids_dataset("ds001")
pt <- read_participants(ds001_path)
sc <- sidecar(pt)
unlink(ds001_path, recursive = TRUE)
}, error = function(e) message("Example requires internet: ", e$message))
# }